@@ -1,6 +1,7 @@
 from .addons_installer import AddonsSuffix
 from .addons_installer import GitOdooAddons
-from .addons_installer import LocalGitSubDirOdooAddons
+from .addons_installer import GitSubDirOdooAddons
+from .addons_installer import LocalSubDirOdooAddons
 from .addons_installer import LocalOdooAddons
 from .addons_installer import OdooAddonsDef
 from .addons_installer import KeySuffix
